[![PyPI version](https://badge.fury.io/py/neuralsampler.svg)](https://badge.fury.io/py/neuralsampler)
[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/drive/1gEUjfsmoinemOb3P6p0UCI3zfYx-T8uI?usp=sharing)

## NeuralSampler - Pytorch

Implementation of Neural Sampler. 

## Install

``` bash
$ pip install neuralsampler
```

or install the latest version by 
``` bash 
pip install -U git+https://JiahaoYao:{password}@github.com/JiahaoYao/neuralsampler.git@main
```


## Usage

```python
import torch
from neuralsampler import neuralsampler
```

## Run the code 

```bash 
python main.py 
```

## Ignore me (random things)
```
this repo is to collect all the random results and reproduce the experiments here 

and then jax 

i will use jax and flax, like shown here: https://github.com/yang-song/score_sde

there are the templates of building the jax neural networks (quite interesting to try this functional programming )
```


## Todo list 
- this library is on the pytorch
- i am also going to prepare the colab notebook 
- the dataset is through the gdown: you can download the dataset from the google drive  
